@@ -13,13 +13,12 @@
 #include <KLocalizedString>
 #include <QStringBuilder>
 
-#include "actionsmodel.h"
 #include "controller.h"
-#include "customemojimodel.h"
+#include "models/actionsmodel.h"
+#include "models/customemojimodel.h"
 #include "neochatconfig.h"
-#include "neochatroom.h"
-#include "roommanager.h"
 #include "neochatuser.h"
+#include "roommanager.h"
 
 using namespace Quotient;
 
