@@ -5,7 +5,6 @@
 
 #include <QQmlFile>
 #include <QQmlFileSelector>
-#include <QQuickTextDocument>
 #include <QStringBuilder>
 #include <QSyntaxHighlighter>
 #include <QTextBlock>
@@ -15,10 +14,9 @@
 #include <Sonnet/BackgroundChecker>
 #include <Sonnet/Settings>
 
-#include "actionsmodel.h"
-#include "completionmodel.h"
+#include "models/actionsmodel.h"
+#include "models/roomlistmodel.h"
 #include "neochatroom.h"
-#include "roomlistmodel.h"
 
 class SyntaxHighlighter : public QSyntaxHighlighter
 {
@@ -107,7 +105,7 @@ ChatDocumentHandler::ChatDocumentHandler(QObject *parent)
 {
     connect(this, &ChatDocumentHandler::roomChanged, this, [this]() {
         m_completionModel->setRoom(m_room);
-        static NeoChatRoom *previousRoom = nullptr;
+        static QPointer<NeoChatRoom> previousRoom = nullptr;
         if (previousRoom) {
             disconnect(previousRoom, &NeoChatRoom::chatBoxTextChanged, this, nullptr);
         }
