@@ -42,19 +42,29 @@
 #include "blurhashimageprovider.h"
 #include "chatdocumenthandler.h"
 #include "clipboard.h"
-#include "collapsestateproxymodel.h"
 #include "controller.h"
-#include "customemojimodel.h"
-#include "devicesmodel.h"
-#include "emojimodel.h"
 #include "filetypesingleton.h"
 #include "joinrulesevent.h"
 #include "linkpreviewer.h"
-#include "keywordnotificationrulemodel.h"
 #include "login.h"
 #include "matriximageprovider.h"
-#include "messageeventmodel.h"
-#include "messagefiltermodel.h"
+#include "models/collapsestateproxymodel.h"
+#include "models/customemojimodel.h"
+#include "models/devicesmodel.h"
+#include "models/emojimodel.h"
+#include "models/keywordnotificationrulemodel.h"
+#include "models/messageeventmodel.h"
+#include "models/messagefiltermodel.h"
+#include "models/publicroomlistmodel.h"
+#include "models/roomlistmodel.h"
+#include "models/searchmodel.h"
+#include "models/serverlistmodel.h"
+#include "models/sortfilterroomlistmodel.h"
+#include "models/sortfilterspacelistmodel.h"
+#include "models/userdirectorylistmodel.h"
+#include "models/userfiltermodel.h"
+#include "models/userlistmodel.h"
+#include "models/webshortcutmodel.h"
 #include "neochatconfig.h"
 #include "neochatroom.h"
 #include "neochatuser.h"
@@ -62,17 +72,9 @@
 #ifdef QUOTIENT_07
 #include "pollhandler.h"
 #endif
-#include "publicroomlistmodel.h"
-#include "roomlistmodel.h"
 #include "roommanager.h"
-#include "serverlistmodel.h"
-#include "sortfilterroomlistmodel.h"
-#include "sortfilterspacelistmodel.h"
 #include "spacehierarchycache.h"
 #include "urlhelper.h"
-#include "userdirectorylistmodel.h"
-#include "userlistmodel.h"
-#include "webshortcutmodel.h"
 #include "windowcontroller.h"
 #ifdef QUOTIENT_07
 #include <keyverificationsession.h>
@@ -80,9 +82,9 @@
 #ifdef HAVE_COLORSCHEME
 #include "colorschemer.h"
 #endif
-#include "completionmodel.h"
+#include "models/completionmodel.h"
+#include "models/statemodel.h"
 #include "neochatuser.h"
-#include "statemodel.h"
 
 #ifdef HAVE_RUNNER
 #include "runner.h"
@@ -219,6 +221,7 @@ int main(int argc, char *argv[])
     qmlRegisterType<MessageEventModel>("org.kde.neochat", 1, 0, "MessageEventModel");
     qmlRegisterType<CollapseStateProxyModel>("org.kde.neochat", 1, 0, "CollapseStateProxyModel");
     qmlRegisterType<MessageFilterModel>("org.kde.neochat", 1, 0, "MessageFilterModel");
+    qmlRegisterType<UserFilterModel>("org.kde.neochat", 1, 0, "UserFilterModel");
     qmlRegisterType<PublicRoomListModel>("org.kde.neochat", 1, 0, "PublicRoomListModel");
     qmlRegisterType<UserDirectoryListModel>("org.kde.neochat", 1, 0, "UserDirectoryListModel");
     qmlRegisterType<ServerListModel>("org.kde.neochat", 1, 0, "ServerListModel");
@@ -228,6 +231,7 @@ int main(int argc, char *argv[])
     qmlRegisterType<LinkPreviewer>("org.kde.neochat", 1, 0, "LinkPreviewer");
     qmlRegisterType<CompletionModel>("org.kde.neochat", 1, 0, "CompletionModel");
     qmlRegisterType<StateModel>("org.kde.neochat", 1, 0, "StateModel");
+    qmlRegisterType<SearchModel>("org.kde.neochat", 1, 0, "SearchModel");
 #ifdef QUOTIENT_07
     qmlRegisterType<PollHandler>("org.kde.neochat", 1, 0, "PollHandler");
 #endif
@@ -265,6 +269,32 @@ int main(int argc, char *argv[])
 #endif
 
     QQmlApplicationEngine engine;
+
+#ifdef HAVE_KDBUSADDONS
+    KDBusService service(KDBusService::Unique);
+    service.connect(&service,
+                    &KDBusService::activateRequested,
+                    &RoomManager::instance(),
+                    [&engine](const QStringList &arguments, const QString &workingDirectory) {
+                        Q_UNUSED(workingDirectory);
+
+                        QWindow *window = windowFromEngine(&engine);
+                        KWindowSystem::updateStartupId(window);
+
+                        WindowController::instance().showAndRaiseWindow(QString());
+
+                        // Open matrix uri
+                        if (arguments.isEmpty()) {
+                            return;
+                        }
+                        auto args = arguments;
+                        args.removeFirst();
+                        for (const auto &arg : args) {
+                            RoomManager::instance().openResource(arg);
+                        }
+                    });
+#endif
+
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
     QObject::connect(&engine, &QQmlApplicationEngine::quit, &app, &QCoreApplication::quit);
     engine.setNetworkAccessManagerFactory(new NetworkAccessManagerFactory());
@@ -294,31 +324,6 @@ int main(int argc, char *argv[])
     QDBusConnection::sessionBus().registerObject("/RoomRunner", &runner, QDBusConnection::ExportScriptableContents);
 #endif
 
-#ifdef HAVE_KDBUSADDONS
-    KDBusService service(KDBusService::Unique);
-    service.connect(&service,
-                    &KDBusService::activateRequested,
-                    &RoomManager::instance(),
-                    [&engine](const QStringList &arguments, const QString &workingDirectory) {
-                        Q_UNUSED(workingDirectory);
-
-                        QWindow *window = windowFromEngine(&engine);
-                        KWindowSystem::updateStartupId(window);
-
-                        WindowController::instance().showAndRaiseWindow(QString());
-
-                        // Open matrix uri
-                        if (arguments.isEmpty()) {
-                            return;
-                        }
-                        auto args = arguments;
-                        args.removeFirst();
-                        for (const auto &arg : args) {
-                            RoomManager::instance().openResource(arg);
-                        }
-                    });
-#endif
-
     QWindow *window = windowFromEngine(&engine);
 
     WindowController::instance().setWindow(window);
