@@ -15,9 +15,12 @@ class Connection;
 class AccountRegistry : public QAbstractListModel
 {
     Q_OBJECT
+    Q_PROPERTY(int accountCount READ count NOTIFY accountCountChanged);
+
 public:
     enum EventRoles {
         ConnectionRole = Qt::UserRole + 1,
+        UserIdRole = Qt::DisplayRole,
     };
 
     static AccountRegistry &instance()
@@ -40,6 +43,9 @@ public:
 
     [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
+Q_SIGNALS:
+    void accountCountChanged();
+
 private:
     AccountRegistry();
 
