@@ -5,13 +5,18 @@
 
 #include <memory>
 
-#include <QImage>
 #include <QJsonArray>
 
 #include <KLocalizedString>
 #include <KNotification>
 #include <KNotificationReplyAction>
 
+#ifdef QUOTIENT_07
+#include <accountregistry.h>
+#else
+#include "neochataccountregistry.h"
+#endif
+
 #include <connection.h>
 #include <csapi/pushrules.h>
 #include <jobs/basejob.h>
@@ -50,10 +55,6 @@ void NotificationsManager::postNotification(NeoChatRoom *room,
                                             const QString &replyEventId,
                                             bool canReply)
 {
-    if (!NeoChatConfig::self()->showNotifications()) {
-        return;
-    }
-
     QPixmap img;
     img.convertFromImage(icon);
     KNotification *notification = new KNotification("message");
@@ -69,8 +70,15 @@ void NotificationsManager::postNotification(NeoChatRoom *room,
 
     notification->setDefaultAction(i18n("Open NeoChat in this room"));
     connect(notification, &KNotification::defaultActivated, this, [=]() {
-        RoomManager::instance().enterRoom(room);
         WindowController::instance().showAndRaiseWindow(notification->xdgActivationToken());
+        if (room->localUser()->id() != Controller::instance().activeConnection()->userId()) {
+#ifdef QUOTIENT_07
+            Controller::instance().setActiveConnection(Accounts.get(room->localUser()->id()));
+#else
+            Controller::instance().setActiveConnection(AccountRegistry::instance().get(room->localUser()->id()));
+#endif
+        }
+        RoomManager::instance().enterRoom(room);
     });
 
     if (canReply) {
@@ -91,9 +99,6 @@ void NotificationsManager::postNotification(NeoChatRoom *room,
 
 void NotificationsManager::postInviteNotification(NeoChatRoom *room, const QString &title, const QString &sender, const QImage &icon)
 {
-    if (!NeoChatConfig::self()->showNotifications()) {
-        return;
-    }
     QPixmap img;
     img.convertFromImage(icon);
     KNotification *notification = new KNotification("invite");
@@ -103,9 +108,9 @@ void NotificationsManager::postInviteNotification(NeoChatRoom *room, const QStri
     notification->setFlags(KNotification::Persistent);
     notification->setDefaultAction(i18n("Open this invitation in NeoChat"));
     connect(notification, &KNotification::defaultActivated, this, [=]() {
+        WindowController::instance().showAndRaiseWindow(notification->xdgActivationToken());
         notification->close();
         RoomManager::instance().enterRoom(room);
-        WindowController::instance().showAndRaiseWindow(notification->xdgActivationToken());
     });
     notification->setActions({i18n("Accept Invitation"), i18n("Reject Invitation")});
     connect(notification, &KNotification::action1Activated, this, [room, notification]() {
@@ -272,7 +277,9 @@ void NotificationsManager::updateNotificationRules(const QString &type)
         if (overrideRule["rule_id"] == ".m.rule.master") {
             bool ruleEnabled = overrideRule["enabled"].toBool();
             m_globalNotificationsEnabled = !ruleEnabled;
-            NeoChatConfig::self()->setShowNotifications(m_globalNotificationsEnabled);
+            if (!m_globalNotificationsSet) {
+                m_globalNotificationsSet = true;
+            }
             Q_EMIT globalNotificationsEnabledChanged(m_globalNotificationsEnabled);
         }
 
