@@ -5,11 +5,6 @@
 
 // Modified from mujx/nheko's TrayIcon.
 
-#include <QAction>
-#include <QIcon>
-#include <QIconEngine>
-#include <QPainter>
-#include <QRect>
 #include <QSystemTrayIcon>
 
 class TrayIcon : public QSystemTrayIcon
