@@ -3,6 +3,7 @@
 
 #include "urlhelper.h"
 
+#include <QFile>
 #include <QtGlobal>
 
 #ifdef Q_OS_ANDROID
@@ -22,3 +23,9 @@ void UrlHelper::openUrl(const QUrl &url)
     job->start();
 #endif
 }
+
+void UrlHelper::copyTo(const QUrl &origin, const QUrl &destination)
+{
+    QFile originFile(origin.toLocalFile());
+    originFile.copy(destination.toLocalFile());
+}
