@@ -4,10 +4,12 @@
 #pragma once
 
 #include <QObject>
+#include <QUrl>
 
 class UrlHelper : public QObject
 {
     Q_OBJECT
 public:
     Q_INVOKABLE void openUrl(const QUrl &url);
+    Q_INVOKABLE void copyTo(const QUrl &origin, const QUrl &destination);
 };
